@@ -34,6 +34,7 @@
 #include "procactions.h"
 #include "procdialogs.h"
 #include "memmaps.h"
+#include "openfiles.h"
 #include "favorites.h"
 #include "load-graph.h"
 #include "cellrenderer.h"
@@ -89,8 +90,15 @@ cb_show_memory_maps (GtkMenuItem *menuitem, gpointer data)
 	create_memmaps_dialog (procdata);
 }
 
-
 void
+cb_show_open_files (GtkMenuItem *menuitem, gpointer data)
+{
+	ProcData *procdata = data;
+	
+	create_openfiles_dialog (procdata);
+}
+
+void		
 cb_show_hidden_processes (GtkMenuItem *menuitem, gpointer data)
 {
 	ProcData * const procdata = data;
@@ -121,17 +129,26 @@ cb_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 		NULL
 	};
 
+	static const gchar *documenters[] = {
+		"Bill Day",
+		"Sun Microsystems",
+		NULL
+	};
+
 	PROCMAN_GETTEXT_ARRAY_INIT(authors);
 
 	gtk_show_about_dialog (
 		NULL,
 		"name",			_("System Monitor"),
-		"comments",		_("System resources monitor"),
+		"comments",		_("View current processes and monitor "
+					  "system state"),
 		"version",		VERSION,
-		"copyright",		"(C) 2001 - 2004 Kevin Vandersloot",
-		"logo-icon-name",	"procman",
+		"copyright",		"Copyright \xc2\xa9 2001-2004 "
+					"Kevin Vandersloot",
+		"logo-icon-name",	"gnome-monitor",
 		"authors",		authors,
-		"translator-credits",	_("translator_credits"),
+		"documenters",		documenters,
+		"translator-credits",	_("translator-credits"),
 		NULL
 		);
 }
@@ -190,6 +207,14 @@ cb_end_process_button_pressed (GtkButton *button, gpointer data)
 }
 
 
+void
+popup_menu_show_open_files (GtkMenuItem *menuitem, gpointer data)
+{
+	ProcData *procdata = data;
+	
+	create_openfiles_dialog (procdata);
+}
+
 void
 cb_info_button_pressed (GtkButton *button, gpointer user_data)
 {
