@@ -21,9 +21,10 @@
 
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
+#include <libgnomevfs/gnome-vfs.h>
 #include <gconf/gconf-client.h>
 #include <glibtop.h>
-#include <pthread.h>
+#include <glibtop/close.h>
 #include "load-graph.h"
 #include "procman.h"
 #include "interface.h"
@@ -32,37 +33,6 @@
 #include "favorites.h"
 #include "callbacks.h"
 
-GtkWidget *app;
-static int simple_view = FALSE;
-pthread_t thread;
-
-
-struct poptOption options[] = {
-  {
-    "simple",
-    's',
-    POPT_ARG_NONE,
-    &simple_view,
-    0,
-    N_("show simple dialog to end processes and logout"),
-    NULL,
-  },
-  {
-    NULL,
-    '\0',
-    0,
-    NULL,
-    0,
-    NULL,
-    NULL
-  }
-};
-
-static void
-load_desktop_files (ProcData *pd)
-{
-	pd->pretty_table = pretty_table_new (pd);
-}
 
 static void
 tree_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
@@ -164,11 +134,10 @@ timeouts_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer
 static void
 color_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
 {
-	ProcData *procdata = data;
+	ProcData * const procdata = data;
 	const gchar *key = gconf_entry_get_key (entry);
 	GConfValue *value = gconf_entry_get_value (entry);
 	const gchar *color = gconf_value_get_string (value);
-	gint i;
 
 	if (!g_strcasecmp (key, "/apps/procman/bg_color")) {
 		gdk_color_parse (color, &procdata->config.bg_color);
@@ -184,7 +153,9 @@ color_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer dat
 		gdk_color_parse (color, &procdata->config.cpu_color[0]);
 		procdata->cpu_graph->colors[2] = procdata->config.cpu_color[0];
 	}
-	else if (g_strrstr (key, "/apps/procman/cpu_color")) {
+	else if (g_str_has_prefix (key, "/apps/procman/cpu_color")) {
+		gint i;
+
 		for (i=1;i<GLIBTOP_NCPU;i++) {
 			gchar *cpu_key;
 			cpu_key = g_strdup_printf ("/apps/procman/cpu_color%d",i);
@@ -224,6 +195,7 @@ procman_data_new (GConfClient *client)
 	pd->tree = NULL;
 	pd->infobox = NULL;
 	pd->info = NULL;
+	pd->pids = g_hash_table_new(g_direct_hash, g_direct_equal);
 	pd->selected_process = NULL;
 	pd->timeout = -1;
 	pd->blacklist = NULL;
@@ -286,7 +258,7 @@ procman_data_new (GConfClient *client)
 	
 	color = gconf_client_get_string (client, "/apps/procman/cpu_color", NULL);
 	if (!color)
-		color = g_strdup ("#f25915e815e8");
+		color = g_strdup ("#0000007200b3");
 	gconf_client_notify_add (client, "/apps/procman/cpu_color", 
 			  	 color_changed_cb, pd, NULL, NULL);
 	gdk_color_parse(color, &pd->config.cpu_color[0]);
@@ -307,7 +279,7 @@ procman_data_new (GConfClient *client)
 	}
 	color = gconf_client_get_string (client, "/apps/procman/mem_color", NULL);
 	if (!color)
-		color = g_strdup ("#f25915e815e8");
+		color = g_strdup ("#000000b3005b");
 	gconf_client_notify_add (client, "/apps/procman/mem_color", 
 			  	 color_changed_cb, pd, NULL, NULL);
 	gdk_color_parse(color, &pd->config.mem_color);
@@ -316,25 +288,13 @@ procman_data_new (GConfClient *client)
 	
 	color = gconf_client_get_string (client, "/apps/procman/swap_color", NULL);
 	if (!color)
-		color = g_strdup ("#212fe32b212f");
+		color = g_strdup ("#008b000000c3");
 	gconf_client_notify_add (client, "/apps/procman/swap_color", 
 			  	 color_changed_cb, pd, NULL, NULL);
 	gdk_color_parse(color, &pd->config.swap_color);
 	g_free (color);
 	
 	get_blacklist (pd, client);
-
-	pd->config.simple_view = FALSE;	
-	if (pd->config.simple_view) {
-		pd->config.width = 325;
-		pd->config.height = 400;
-		pd->config.whose_process = 1;
-		pd->config.show_more_info = FALSE;
-		pd->config.show_tree = FALSE;
-		pd->config.show_kill_warning = TRUE;
-		pd->config.show_threads = FALSE;
-		pd->config.current_tab = 0;
-	}	
 	
 	/* Sanity checks */
 	swidth = gdk_screen_width ();
@@ -369,8 +329,8 @@ procman_free_data (ProcData *procdata)
 {
 
 	proctable_free_table (procdata);
-	
-	//pretty_table_free (procdata->pretty_table);
+	g_hash_table_destroy(procdata->pids);
+	/* pretty_table_free (procdata->pretty_table); */
 	
 	g_free (procdata);
 	
@@ -498,16 +458,12 @@ procman_save_config (ProcData *data)
 	GConfClient *client = data->client;
 	gint width, height, pane_pos;
 
-	if (!data)
-		return;
-		
-	if (data->config.simple_view)
-		return;
+	g_return_if_fail(data != NULL);
 		
 	procman_save_tree_state (data->client, data->tree, "/apps/procman/proctree");
 	procman_save_tree_state (data->client, data->disk_list, "/apps/procman/disktreenew");
 		
-	gdk_window_get_size (app->window, &width, &height);
+	gdk_window_get_size (data->app->window, &width, &height);
 	data->config.width = width;
 	data->config.height = height;
 	
@@ -535,57 +491,43 @@ main (int argc, char *argv[])
 	GnomeProgram *procman;
 	GConfClient *client;
 	ProcData *procdata;
-	GValue value = {0,};
-	poptContext pctx;
-	char **args;
 	
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
 	procman = gnome_program_init ("gnome-system-monitor", VERSION, 
-				      LIBGNOMEUI_MODULE, argc, argv, 
-			    	      GNOME_PARAM_POPT_TABLE, options, 
+				      LIBGNOMEUI_MODULE, argc, argv,
 				      GNOME_PARAM_APP_DATADIR,DATADIR, NULL);
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/procman.png");
+	gtk_window_set_default_icon_name ("gnome-monitor");
 		    
 	gconf_init (argc, argv, NULL);
 			    
 	client = gconf_client_get_default ();
 	gconf_client_add_dir(client, "/apps/procman", GCONF_CLIENT_PRELOAD_NONE, NULL);
-        		    
-	/*g_value_init (&value, G_TYPE_POINTER);
-  	g_object_get_property (G_OBJECT(procman),
-                               GNOME_PARAM_POPT_CONTEXT, &value);
-        (poptContext)pctx = g_value_get_pointer (&value);
-                               
-	args = (char**) poptGetArgs (pctx);
-	poptFreeContext(pctx);*/
-	
+
+	gnome_vfs_init ();
 	glibtop_init ();
 	
 	procdata = procman_data_new (client);
 	procdata->client = client;
-	
-	if (procdata->config.simple_view) 
-		app = create_simple_view_dialog (procdata);
-	else 
-		app = create_main_window (procdata);
-	
-	load_desktop_files (procdata);
+	pretty_table_new (procdata);
+
+	create_main_window (procdata);
 	
 	proctable_update_all (procdata);
 		 
-	
-	if (!app)
-		return 0;  
+	g_return_val_if_fail(procdata->app != NULL, 1);
 			
- 	gtk_widget_show (app);	
+ 	gtk_widget_show (procdata->app);
  	
 	gtk_main ();
 	
 	procman_free_data (procdata);
 
+	glibtop_close ();
+	gnome_vfs_shutdown ();
+
 	return 0;
 }
 
